<?php
declare(strict_types=1);

namespace IntiTest\Media\Provider;

use Inti\Media\ConfigProvider;
use Inti\Media\Service\ImageManager;
use Inti\Test\TestCase\ApplicationTestTrait;
use PHPUnit\Framework\TestCase;
use WP_Post;

use function get_post;
use function get_post_meta;
use function wp_get_attachment_url;

/**
 * Class ImageProviderTest
 *
 * @package IntiTest\Media\Provider
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-bartog
 *
 * @runTestsInSeparateProcesses
 */
final class ImageProviderTest extends TestCase
{
    use ApplicationTestTrait;

    protected array $providers = [
        \Laminas\Filter\ConfigProvider::class,
        \Inti\Db\ConfigProvider::class,
        \Inti\Filter\ConfigProvider::class,
        \Inti\Provider\ConfigProvider::class,
        \Inti\Wp\ConfigProvider::class,
        \Inti\Wp\Provider\ConfigProvider::class,
        ConfigProvider::class,
    ];

    protected array $config = [
        'db_connections' => [
            'default' => [
                'host' => 'autokreso-baza',
                'user' => 'root',
                'password' => 'JrtbKN9WD',
                'dbname' => 'test_motostop_novo'
            ],
        ],
        'media' => [
            ImageManager::class => [
                'root' => __DIR__ . '/../data',
            ],
        ],
    ];

    protected ImageManager $imageManager;

    protected function setUp(): void
    {
        if (!defined('ABSPATH')) {
            define('ABSPATH', realpath(__DIR__ . '/../../wordpress') . '/');
        }

        $this->runApplication();
        $this->imageManager = $this->container->get(ImageManager::class);
    }

    public function testCanGetImagePosts()
    {
        $id = $this->imageManager->getImageId('image.webp');

        $post = get_post($id);
        $this->assertInstanceOf(WP_Post::class, $post);
        $this->assertEquals('image.webp', get_post_meta($post->ID, '_wp_attached_file', true));
    }

    public function testCanGetAttachmentUrl()
    {
        $id = $this->imageManager->getImageId('image.webp');

        $url = wp_get_attachment_url($id);
        $this->assertEquals('/media/image.webp', $url);
    }
}
